Module auth

Module auth 

etcd’s authentication and authorization API.

These API endpoints are used to manage users and roles.

Structs

NewUser
Paramters used to create a new etcd user.
Role
An authorization role.
RoleUpdate
Parameters used to update an existing authorization role.
User
An existing etcd user with a list of their granted roles.
UserDetail
An existing etcd user with details of granted roles.
UserUpdate
Parameters used to update an existing etcd user.

Enums

AuthChange
The type returned when the auth system is successfully enabled or disabled.

Functions

create_role
Creates a new role.
create_user
Creates a new user.
delete_role
Deletes a role.
delete_user
Deletes a user.
disable
Attempts to disable the auth system.
enable
Attempts to enable the auth system.
get_role
Get a role.
get_roles
Gets all roles.
get_user
Get a user.
get_users
Gets all users.
status
Determines whether or not the auth system is enabled.
update_role
Updates an existing role.
update_user
Updates an existing user.