pub struct Role { /* private fields */ }Expand description
An authorization role.
Implementations
Sourceimpl Role
impl Role
Sourcepub fn grant_kv_read_permission<K>(&mut self, key: K)
pub fn grant_kv_read_permission<K>(&mut self, key: K)
Grants read permission for a key in etcd’s key-value store to this role.
Sourcepub fn grant_kv_write_permission<K>(&mut self, key: K)
pub fn grant_kv_write_permission<K>(&mut self, key: K)
Grants write permission for a key in etcd’s key-value store to this role.
Sourcepub fn kv_read_permissions(&self) -> &[String]
pub fn kv_read_permissions(&self) -> &[String]
Returns a list of keys in etcd’s key-value store that this role is allowed to read.
Sourcepub fn kv_write_permissions(&self) -> &[String]
pub fn kv_write_permissions(&self) -> &[String]
Returns a list of keys in etcd’s key-value store that this role is allowed to write.