pub enum WatchError {
Other(Vec<Error>),
Timeout,
}Expand description
An error returned by kv::watch.
Variants
Other(Vec<Error>)
An error for each failed request to an etcd member.
Timeout
The supplied timeout was reached before any request successfully completed.