etcd’s authentication and authorization API.
These API endpoints are used to manage users and roles.
Structs
- NewUser
- Paramters used to create a new etcd user.
- Role
- An authorization role.
- Role
Update - Parameters used to update an existing authorization role.
- User
- An existing etcd user with a list of their granted roles.
- User
Detail - An existing etcd user with details of granted roles.
- User
Update - Parameters used to update an existing etcd user.
Enums
- Auth
Change - The type returned when the auth system is successfully enabled or disabled.
Functions
- create_
role - Creates a new role.
- create_
user - Creates a new user.
- delete_
role - Deletes a role.
- delete_
user - Deletes a user.
- disable
- Attempts to disable the auth system.
- enable
- Attempts to enable the auth system.
- get_
role - Get a role.
- get_
roles - Gets all roles.
- get_
user - Get a user.
- get_
users - Gets all users.
- status
- Determines whether or not the auth system is enabled.
- update_
role - Updates an existing role.
- update_
user - Updates an existing user.